@@ -17,10 +17,14 @@ from executorlib.task_scheduler.file.subprocess_spawner import (
 )
 
 try:
-    from executorlib.task_scheduler.file.queue_spawner import execute_with_pysqa
+    from executorlib.task_scheduler.file.queue_spawner import (
+        execute_with_pysqa,
+        terminate_with_pysqa,
+    )
 except ImportError:
     # If pysqa is not available fall back to executing tasks in a subprocess
     execute_with_pysqa = execute_in_subprocess  # type: ignore
+    terminate_with_pysqa = None  # type: ignore
 
 
 class FileTaskScheduler(TaskSchedulerBase):
@@ -58,8 +62,6 @@ class FileTaskScheduler(TaskSchedulerBase):
         resource_dict.update(
             {k: v for k, v in default_resource_dict.items() if k not in resource_dict}
         )
-        if execute_function == execute_in_subprocess and terminate_function is None:
-            terminate_function = terminate_subprocess
         self._process_kwargs = {
             "resource_dict": resource_dict,
             "future_queue": self._future_queue,
@@ -80,7 +82,7 @@ class FileTaskScheduler(TaskSchedulerBase):
 def create_file_executor(
     resource_dict: dict,
     max_workers: Optional[int] = None,
-    backend: str = "flux_submission",
+    backend: Optional[str] = None,
     max_cores: Optional[int] = None,
     cache_directory: Optional[str] = None,
     flux_executor=None,
@@ -92,6 +94,7 @@ def create_file_executor(
     block_allocation: bool = False,
     init_function: Optional[Callable] = None,
     disable_dependencies: bool = False,
+    execute_function: Callable = execute_with_pysqa,
 ):
     if block_allocation:
         raise ValueError(
@@ -109,9 +112,15 @@ def create_file_executor(
     check_executor(executor=flux_executor)
     check_nested_flux_executor(nested_flux_executor=flux_executor_nesting)
     check_flux_log_files(flux_log_files=flux_log_files)
+    if execute_function != execute_in_subprocess:
+        terminate_function = terminate_with_pysqa  # type: ignore
+    else:
+        terminate_function = terminate_subprocess  # type: ignore
     return FileTaskScheduler(
         resource_dict=resource_dict,
         pysqa_config_directory=pysqa_config_directory,
-        backend=backend.split("_submission")[0],
+        backend=backend,
         disable_dependencies=disable_dependencies,
+        execute_function=execute_function,
+        terminate_function=terminate_function,
     )
